@@ -12,19 +12,27 @@ import envx
 
 
 def make_con_info(
-        env_file_name: str = 'redis.env'
+        env_file_name: str = 'local.redis.env'
 ):
     # ---------------- 固定设置 ----------------
     inner_env = envx.read(file_name=env_file_name)
-    if len(inner_env) == 0:
-        showlog.warning('Please check that the file exists and meets the requirements. File:[%s]' % env_file_name)
-        return
+    if inner_env is None or len(inner_env) == 0:
+        showlog.warning('[%s]文件不存在或文件填写错误！' % env_file_name)
+        exit()
     else:
+        max_connections = inner_env.get('max_connections')
+        if max_connections is not None:
+            try:
+                max_connections = int(max_connections)
+            except:
+                showlog.warning('max_connections必须是数字！')
+        else:
+            max_connections = None
         con_info = {
             "host": inner_env.get('host', 'localhost'),
             "port": int(inner_env.get('port', '6379')),
             "password": inner_env.get('password'),
-            "max_connections": int(inner_env.get('max_connections', '10')),
+            "max_connections": max_connections,
         }
         return con_info
 
@@ -46,7 +54,6 @@ class Basics:
             self.port = con_info.get('port')
             self.pwd = con_info.get('password')
             self.max_connections = con_info.get('max_connections')
-            self.connection = self.connect()  # 执行连接
         else:
             if db is None:
                 self.con_db = 0
@@ -56,12 +63,13 @@ class Basics:
             self.port = port
             self.pwd = password
             self.max_connections = max_connections
-            self.connection = self.connect()  # 执行连接
+        self.pool = self.make_connect_pool()
+        self.conn = self.connect()
 
-    def connect(
+    def make_connect_pool(
             self
     ):
-        # 执行连接
+        # 使用连接池连接，节省每次连接用的时间
         pool = redis.ConnectionPool(
             host=self.host,
             port=self.port,
@@ -69,209 +77,212 @@ class Basics:
             db=self.con_db,
             max_connections=self.max_connections
         )
-        connection = redis.Redis(connection_pool=pool)
+        return pool
+
+    def connect(
+            self
+    ):
+        # 从连接池中拿出一个连接
+        connection = redis.Redis(
+            connection_pool=self.pool
+        )
         return connection
 
     def get_db_key_list(
             self,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         """
         读取指定数据库的键列表
         """
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                inner_keys = conn.keys()
-                break
+                inner_keys = self.conn.keys()
+                key_list = list()
+                for key in inner_keys:
+                    key_list.append(key.decode())
+                return key_list
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
-
-        key_list = list()
-        for key in inner_keys:
-            key_list.append(key.decode())
-        return key_list
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def read_list_key_values_length(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         """
         读取指定库的指定键的值列表元素数量
         """
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                values_count = conn.llen(key)  # 获取列表元素个数
+                values_count = self.conn.llen(key)  # 获取列表元素个数
                 return values_count
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def read_list_key_values(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         """
         读取指定库的指定键的所有值列表
         """
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                values_count = conn.llen(key)  # 获取列表元素个数
-                break
+                values_count = self.conn.llen(key)  # 获取列表元素个数
+                values = list()
+                for i in range(values_count):
+                    while True:
+                        try:
+                            each_value = self.conn.lindex(key, i)
+                            break
+                        except:
+                            showlog.error('获取失败，准备重连')
+                            self.conn = self.connect()
+                    if each_value is not None:
+                        values.append(each_value.decode())
+                return values
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
-
-        values = list()
-        for i in range(values_count):
-            while True:
-                try:
-                    each_value = conn.lindex(key, i)
-                    break
-                except:
-                    showlog.error('获取失败，准备重连')
-                    self.connection = self.connect()
-            if each_value is not None:
-                values.append(each_value.decode())
-        return values
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def read_list_first_value(
             self,
-            key
+            key,
+            auto_reconnect: bool = True  # 自动重连
     ):
         """
         获取列表的第一个元素
         """
         while True:
             try:
-                last_value = self.connection.lindex(key, 0)
+                last_value = self.conn.lindex(key, 0)
                 return last_value
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def read_list_last_value(
             self,
-            key
+            key,
+            auto_reconnect: bool = True  # 自动重连
     ):
         """
         获取列表的最后一个元素
         """
         while True:
             try:
-                last_value = self.connection.lindex(key, -1)
+                last_value = self.conn.lindex(key, -1)
                 return last_value
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def list_add_l(
             self,
             key,
             value,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 在list左侧添加值
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                return conn.lpush(key, value)
+                return self.conn.lpush(key, value)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def list_add_r(
             self,
             key,
             value,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 在list右侧添加值
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                return conn.rpush(key, value)
+                return self.conn.rpush(key, value)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def list_pop_l(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 从左侧出队列
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                return conn.lpop(key)
+                return self.conn.lpop(key)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def list_pop_r(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 从右侧侧出队列
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
-
         while True:
             try:
-                return conn.rpop(key)
+                return self.conn.rpop(key)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def set_string(
             self,
             name,
             value,
-            connection=None,
             ex=None,
-            px=None
+            px=None,
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 设置键值，ex过期时间（秒），px过期时间（毫秒）
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                return conn.set(
+                return self.conn.set(
                     name,
                     value,
                     ex=ex,
@@ -280,136 +291,142 @@ class Basics:
                     xx=False
                 )
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def get_string(
             self,
             name,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 获取键值
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                return conn.get(name)
+                return self.conn.get(name)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def delete_string(
             self,
             name,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 删除键值
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                return conn.delete(name)
+                return self.conn.delete(name)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def count_set(
             self,
             key,
             value,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 键 计数 设定值
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                return conn.set(name=key, value=value)
+                return self.conn.set(name=key, value=value)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def count_add(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 键 计数 增加1
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                return conn.incr(key)
+                return self.conn.incr(key)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def count_reduce(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 键 计数 减少1
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                return conn.decr(key)
+                return self.conn.decr(key)
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
     def count_get(
             self,
             key,
-            connection=None
+            auto_reconnect: bool = True  # 自动重连
     ):
         # 键 计数 获取值
-        if connection is None:
-            conn = self.connection
-        else:
-            conn = connection
         while True:
             try:
-                count_value = conn.get(key)
+                count_value = self.conn.get(key)
                 if count_value is None:
                     return
                 else:
                     return count_value.decode()
             except:
-                showlog.error('获取失败，准备重连')
-                self.connection = self.connect()
+                pass
+            if auto_reconnect is True:
+                showlog.error('获取失败，尝试重连...')
+                self.conn = self.connect()
+            else:
+                return
 
 
 def list_add_r(
         key,
         value,
-        db: str = None,
+        db: int = None,
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'redis.env'
 ):
     # ---------------- 固定设置 ----------------
     if con_info is None:
-        con_info = make_con_info(env_file_name=env_file_name)
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
     else:
         pass
     if db is None:
-        inner_db = db
+        db = 0
     else:
-        inner_db = None
+        pass
+    con_info['db'] = db
     # ---------------- 固定设置 ----------------
     basics = Basics(
-        db=inner_db,
         con_info=con_info
     )
     return basics.list_add_r(
@@ -420,22 +437,24 @@ def list_add_r(
 
 def list_pop_l(
         key,
-        db: str = None,
+        db: int = None,
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'redis.env'
 ):
     # ---------------- 固定设置 ----------------
     if con_info is None:
-        con_info = make_con_info(env_file_name=env_file_name)
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
     else:
         pass
     if db is None:
-        inner_db = db
+        db = 0
     else:
-        inner_db = None
+        pass
+    con_info['db'] = db
     # ---------------- 固定设置 ----------------
     basics = Basics(
-        db=inner_db,
         con_info=con_info
     )
     return basics.list_pop_l(
@@ -445,22 +464,24 @@ def list_pop_l(
 
 def read_list_key_values(
         key,
-        db: str = None,
+        db: int = None,
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'redis.env'
 ):
     # ---------------- 固定设置 ----------------
     if con_info is None:
-        con_info = make_con_info(env_file_name=env_file_name)
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
     else:
         pass
     if db is None:
-        inner_db = db
+        db = 0
     else:
-        inner_db = None
+        pass
+    con_info['db'] = db
     # ---------------- 固定设置 ----------------
     basics = Basics(
-        db=inner_db,
         con_info=con_info
     )
     return basics.read_list_key_values(
@@ -469,7 +490,7 @@ def read_list_key_values(
 
 
 def keys(
-        db: str = None,
+        db: int = None,
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'redis.env'
 ):
@@ -478,16 +499,18 @@ def keys(
     """
     # ---------------- 固定设置 ----------------
     if con_info is None:
-        con_info = make_con_info(env_file_name=env_file_name)
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
     else:
         pass
     if db is None:
-        inner_db = db
+        db = 0
     else:
-        inner_db = None
+        pass
+    con_info['db'] = db
     # ---------------- 固定设置 ----------------
     basics = Basics(
-        db=inner_db,
         con_info=con_info
     )
     return basics.get_db_key_list()
@@ -495,15 +518,23 @@ def keys(
 
 def read_list_first_value(
         key,
+        db: int = None,
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'redis.env'
 ):
     # 获取列表的第一个元素
     # ---------------- 固定设置 ----------------
     if con_info is None:
-        con_info = make_con_info(env_file_name=env_file_name)
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
     else:
         pass
+    if db is None:
+        db = 0
+    else:
+        pass
+    con_info['db'] = db
     # ---------------- 固定设置 ----------------
     basics = Basics(
         con_info=con_info
@@ -515,15 +546,23 @@ def read_list_first_value(
 
 def read_list_last_value(
         key,
+        db: int = None,
         con_info: dict = None,  # 若指定，将优先使用
         env_file_name: str = 'redis.env'
 ):
     # 获取列表的最后一个元素
     # ---------------- 固定设置 ----------------
     if con_info is None:
-        con_info = make_con_info(env_file_name=env_file_name)
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
     else:
         pass
+    if db is None:
+        db = 0
+    else:
+        pass
+    con_info['db'] = db
     # ---------------- 固定设置 ----------------
     basics = Basics(
         con_info=con_info
